pecos.error\_models.noise\_impl\_old.memory\_noise
==================================================

.. automodule:: pecos.error_models.noise_impl_old.memory_noise







   .. rubric:: Functions

   .. autosummary::

      noise_tq_mem
